@@ -231,6 +231,13 @@ class DtUtil:
     if UniUtil.get_os() == 'Windows':
         locale.setlocale(locale.LC_CTYPE, 'chinese')
 
+    @staticmethod
+    def convert_ts_to_date(src_ts_ms: int):
+        """把13位毫秒级时间戳格式化日期
+        @param src_ts_ms:源13位毫秒级时间戳
+        """
+        return dt.datetime.fromtimestamp(src_ts_ms / 1000)
+
     @staticmethod
     def convert_date_str_format(src_dt_str: str, src_df: str = DF_STD_SEC, dst_df: str = DF_CHN_DAY):
         """把日期字符串格式化成其他格式的日期字符串
@@ -238,7 +245,7 @@ class DtUtil:
         @param src_df:源日期字符串格式
         @param dst_df:目标日期字符串格式
         """
-        return dt.datetime.strftime(dt.datetime.strptime(src_dt_str, src_df), dst_df)
+        return DtUtil.convert_date_to_str(DtUtil.convert_str_to_date(src_dt_str, src_df), dst_df)
 
     @staticmethod
     def convert_date_to_str(src_dt: dt.datetime = dt.datetime.now(), dst_df: str = DF_STD_SEC):
@@ -248,7 +255,14 @@ class DtUtil:
         """
         if dst_df == DtUtil.DF_INFLUX:
             src_dt += relativedelta(hours=-8)
-        return dt.datetime.strftime(src_dt, dst_df)
+        res = dt.datetime.strftime(src_dt, dst_df)
+        if dst_df == DtUtil.DF_INFLUX:
+            mt = str(src_dt.timestamp()).split('.')
+            m1 = mt[0]
+            m2 = mt[1][:3]
+            m3 = 'Z' if m2 == '0' else f'.{m2}Z'
+            res = res.replace('Z', m3)
+        return res
 
     @staticmethod
     def convert_str_to_date(src_dt_str: str, src_df: str = DF_STD_SEC):
